function [xm,ym,zm] = geo2mag(xg,yg,zg,time)
% GEO2MAG converts from cartesian geocentric to geomagnetic coordinates
%	[XM,YM,ZM] = GEO2MAG(XG,YG,ZG,TIME) Converts from cartesian geocentric
%	coordinates <XG,YG,ZG> to cartesian geomagnetic coordinates <XM,YM,ZM>,
%	using the Earth's dipole vector, calculated using the IGRF model. The dipole
%	vector is calculated using the TIME variable, which must be a MATLAB DATENUM
%	variable. XG,YG,ZG can be any size, but must all be the same size, or
%	scalar.
%
%------------------------------------------------------------------------------%
%
%   Version 1.0  Date: 2016/02/05
%
%   Copyright 2016 Aaron Hendry <aaron@hendry.co.nz>
%   Otago University Space Physics Department, Dunedin, New Zealand
%       <http://www.physics.otago.ac.nz/space>
%   Released under the Simplified BSD License:
%       <http://opensource.org/licenses/BSD-2-Clause>
%
%------------------------------------------------------------------------------%

[clat,slat,clon,slon] = dipole(time);

xy = xg*clon+yg*slon;
xm = xy*clat - zg*slat;
ym = yg*clon - xg*slon;
zm = xy*slat + zg*clat;